#!/usr/bin/env python
# -*- coding: utf-8 -*-
# 
# Copyright 2002-2005 Zuza Software Foundation
# 
# This file is part of translate.
#
# translate is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# translate is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with translate; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

"""translate.storage is part of the translate package
It contains classes that represent various storage formats for localization

@group Primary Localisation: xliff pypo cpo pocommon po poheader poparser base factory
@group Bilingual: ts2 ts oo lisa tmx tbx wordfast qph poxliff
@group Monolingual: dtd properties ini rc ical csvl10n html php txt subtitles symbian tiki skype
@group OpenDocument Format: xml_extract odf*
@group Binary: qm mo
@group Version Control: versioncontrol
@group Placeables: placeables
@group Other file processing: directory xpi zip statsdb statistics
@group Other: benchmark tmdb xml_name
"""

